/*
     This file is part of GNUnet.
     (C) 2001, 2002 Christian Grothoff (and other contributing authors)

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/
/**
 * Logging.
 * @author Christian Grothoff
 * @file include/util/logging.h
 **/
#ifndef LOGGING_H
#define LOGGING_H

#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <stdarg.h>
#include <stdlib.h>


#define LOG_NOTHING    0
#define LOG_FATAL      1
#define LOG_ERROR      2
#define LOG_FAILURE    3
#define LOG_WARNING    4
#define LOG_MESSAGE    5
#define LOG_INFO       6
#define LOG_DEBUG      7
#define LOG_EVERYTHING 9

#define DEBUG debug__
#define WARNING warning__
#define ERROR error__
#define INFO info__
#define MESSAGE message__
#define FAILURE failure__

void initLogging(char * logfilename,
		 int loglevel);

void initLoggingFile(FILE * f,
		     int loglevel);

void setLogLevel(int i);

void doneLogging();

/**
 * Errexit - log an error message and exit.
 * Note that this method explicitly also writes
 * an null-termination at the end of the message
 * to signal the waiting parent that the child is
 * aborting.
 * @param format the string describing the error message
 **/
void errexit(const char *format, ...);

/**
 * Log a debug message
 * @param format the string describing the error message
 **/
void print(const char *format, ...);

/**
 * @param format the string describing the error message
 **/
void info__(const char *format, ...);

/**
 * @param format the string describing the error message
 **/
void message__(const char *format, ...);

/**
 * @param format the string describing the error message
 **/
void warning__(const char *format, ...);

/**
 * @param format the string describing the error message
 **/
void error__(const char *format, ...);

/**
 * @param format the string describing the error message
 **/
void debug__(const char *format, ...);

/**
 * @param format the string describing the error message
 **/
void failure__(const char *format, ...);




#endif
